#! /usr/bin/env python
## netconf - A switch printer tool
## Copyright (C) 2002 Red Hat, Inc.
## Copyright (C) 2002 Than Ngo <than@redhat.com>

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import sys

PROGDIR = '/usr/share/redhat-switch-printer/'

if not "/usr/lib/rhs/python" in sys.path:
    sys.path.append("/usr/lib/rhs/python")

if not PROGDIR in sys.path:
    sys.path.append(PROGDIR)

import signal
import os
import os.path
import string
import gettext
from functions import *


##
## I18N
##
gettext.bindtextdomain(PROGNAME, '/usr/share/locale')
gettext.textdomain(PROGNAME)
_ = gettext.gettext

import GDK
import gtk
import libglade
import gnome
import gnome.ui
import gnome.help


class mainDialog:
    def __init__(self):
        pass

    def main(self):
        glade_file = 'redhat-switch-printer.glade'

        if not os.path.isfile(glade_file):
            glade_file = GLADEPATH + glade_file
        if not os.path.isfile(glade_file):
            glade_file = PROGDIR + glade_file

        self.xml = libglade.GladeXML(glade_file, None, domain=PROGNAME)

        self.xml.signal_autoconnect(
            {
            'on_cancelB_clicked' : self.on_cancelB_clicked,
            'on_okB_clicked' : self.on_okB_clicked,
            'on_aboutB_clicked' : self.on_aboutB_clicked,
            })

        self.dialog = self.xml.get_widget('window')
        self.lprng_widget = self.xml.get_widget('lprngRB')
        self.cups_widget = self.xml.get_widget('cupsRB')
        
        self.dialog.connect('delete-event', self.on_Dialog_delete_event)
        self.dialog.connect('hide', gtk.mainquit)
        self.load_icon('switch-printer.xpm', self.dialog)
        self.xml.get_widget('lprPixmap').load_file(PROGDIR+'pixmaps/switch-printer.png')

        self.hydrate()
        gtk.mainloop()
        
    def on_Dialog_delete_event(self, *args):
        gtk.mainquit()

    def on_cancelB_clicked(self, button):
        gtk.mainquit()

    def on_okB_clicked(self, button):
        if self.lprng_widget.get_active():
            switch(LPRNG)
        elif self.cups_widget.get_active():
            switch(CUPS)

        self.dialog.hide()
        self.infoDialog()
        gtk.mainquit()

    def on_aboutB_clicked(self, button):
        self.aboutDialog()

    def hydrate(self):
        self.xml.get_widget('lprLabel').set_text(TEXT)
        self.xml.get_widget('frame').set_label(_('Available Printing System'))
        printer_list = get_printer()

        if len(printer_list) == 0:
            warningDialog()
            sys.exit(1)

        # show printer checkbox
        for printer in printer_list:
            if printer == PRINTER[LPRNG]:
                self.lprng_widget.show()
            if printer == PRINTER[CUPS]:
                self.cups_widget.show()

        # activate default printer
        printer = get_default_printer(printer_list)
        if printer == PRINTER[LPRNG]:
            self.lprng_widget.set_active(TRUE)
        elif printer == PRINTER[CUPS]:
                self.cups_widget.set_active(TRUE)

    def aboutDialog(self):
        dlg = gnome.ui.GnomeAbout(TITLE, VERSION, COPYRIGHT, AUTORS, INFO_TEXT)
        dlg.run_and_close()

    def infoDialog(self):
        dlg = gnome.ui.GnomeMessageBox(INFO_TEXT1, 'info', _('Close'))
        dlg.run_and_close()

    def warningDialog(self):
        dlg = gnome.ui.GnomeMessageBox(WARNING_TEXT, 'warning', _('Close'))
        dlg.run_and_close()

    def get_icon(self, pixmap_file, dialog):
        fn = pixmap_file
        if not os.path.exists(pixmap_file):
            pixmap_file = "pixmaps/" + fn
        if not os.path.exists(pixmap_file):
            pixmap_file = "../pixmaps/" + fn
        if not os.path.exists(pixmap_file):
            pixmap_file = PROGDIR + fn
        if not os.path.exists(pixmap_file):
            pixmap_file = PROGDIR + "pixmaps/" + fn
        if not os.path.exists(pixmap_file):
            return None, None

        pix, mask = gtk.create_pixmap_from_xpm(dialog, None, pixmap_file)
        return pix, mask

    def load_icon(self, pixmap_file, dialog):
        if not dialog: return

        pix, mask = self.get_icon(pixmap_file, dialog)
        if not pix: return

        gtk.GtkPixmap(pix, mask)
        if dialog: dialog.set_icon(pix, mask)

    def rootWarning(self, errMsg):
        dlg = gnome.ui.GnomeMessageBox(errMsg, 'warning', _('Close'))
        dlg.run_and_close()
        
# make ctrl-C work
if __name__ == '__main__':
    signal.signal (signal.SIGINT, signal.SIG_DFL)
    dlg = mainDialog().main()
    
    sys.exit(0)
